@@ -1,5 +1,5 @@
 from uuid import UUID
-from typing import Dict, List, Optional
+from typing import Dict, Optional
 from enum import Enum, auto, unique
 
 from pydantic import BaseModel
@@ -11,26 +11,27 @@ class AutoNameEnum(Enum):
 
 
 @unique
-class EventType(AutoNameEnum):
+class EventType(str, AutoNameEnum):
     """MO Trigger EventType.
 
     EventType for trigger registry
     """
 
-    ON_BEFORE = auto()
-    ON_AFTER = auto()
+    ON_BEFORE: str = auto()
+    ON_AFTER: str = auto()
 
 
 @unique
-class RequestType(AutoNameEnum):
+class RequestType(str, AutoNameEnum):
     """MO Trigger RequestType.
 
     Support requests for :class:`RequestHandler`.
     """
 
-    CREATE = auto()
-    EDIT = auto()
-    TERMINATE = auto()
+    CREATE: str = auto()
+    EDIT: str = auto()
+    TERMINATE: str = auto()
+    REFRESH: str = auto()
 
 
 class MOTriggerPayload(BaseModel):
@@ -38,22 +39,14 @@ class MOTriggerPayload(BaseModel):
 
     See: https://os2mo.readthedocs.io/en/development/api/triggers.html#the-trigger-function for details.
 
-    Note: data is dependent on the `event_type, `request_type` and `role_type`.
+    Note: request is dependent on the `event_type, `request_type` and `role_type`.
     """
 
     class Config:
         schema_extra = {
             "example": {
                 "event_type": "ON_BEFORE",
-                "request": {
-                    "data": {
-                        "clamp": True,
-                        "name": "Havtorn Kommune",
-                        "uuid": "fb2d158f-114e-5f67-8365-2c520cf10b58",
-                        "validity": {"from": "2021-02-09"},
-                    },
-                    "type": "org_unit",
-                },
+                "request": {},
                 "request_type": "EDIT",
                 "role_type": "org_unit",
                 "uuid": "fb2d158f-114e-5f67-8365-2c520cf10b58",
@@ -76,8 +69,8 @@ class MOTriggerRegister(BaseModel):
     class Config:
         schema_extra = {
             "example": {
-                "event_type": 0,
-                "request_type": 0,
+                "event_type": "ON_BEFORE",
+                "request_type": "CREATE",
                 "role_type": "org_unit",
                 "url": "/triggers/ou/create",
                 "timeout": 60,
